==> nextcloud-13.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/pl.js <==
OC.L10N.register(
    "serverinfo",
    {
    "Load average" : "Średnie obciążenie",
    "Last minute" : "Ostatnia minuta",
    "Memory info not available" : "Informacja o pamięci jest niedostępna",
    "Total" : "Suma",
    "Current usage" : "Aktualne użycie",
    "Users" : "Użytkownicy",
    "Groups" : "Grupy",
    "Links" : "Linki",
    "Federated sent" : "Wysłane do federacji",
    "Federated received" : "Otrzymane z federacji",
    "Last 24 hours" : "Ostatnie 24 godziny",
    "Last 1 hour" : "Ostatnia 1 godzina",
    "Last 5 mins" : "Ostatnie 5 minut",
    "Monitoring" : "Monitoring",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Zapewnia przydatne informacje o serwerze, takie jak obciążenie procesora, użycie pamięci RAM, wykorzystanie dysku, liczba użytkowników itp.",
    "CPU load" : "Obciążenie procesora",
    "Memory usage" : "Użycie pamięci",
    "Active users" : "Aktywni użytkownicy",
    "Shares" : "Udziały",
    "Storage" : "Magazyn",
    "Users:" : "Użytkownicy:",
    "Files:" : "Pliki:",
    "PHP" : "PHP",
    "Version:" : "Wersja:",
    "Memory Limit:" : "Limit pamięci:",
    "Max Execution Time:" : "Maksymalny czas wykonania:",
    "Upload max size:" : "Limit wielkości przesyłanego pliku (upload_max_filesize):",
    "Database" : "Baza danych",
    "Type:" : "Rodzaj:",
    "Size:" : "Wielkość:",
    "External monitoring tool" : "Zewnętrzne narzędzie monitorujące",
    "You can connect an external monitoring tool by using this end point: " : "Możesz połączyć zewnętrzne narzędzie monitorujące używając tego adresu:"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");

==> nextcloud-15.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/pl.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Informacje o CPU niedostępne",
    "Load average" : "Średnie obciążenie",
    "Last minute" : "Ostatnia minuta",
    "Memory info not available" : "Informacja o pamięci jest niedostępna",
    "Total" : "Suma",
    "Current usage" : "Aktualne użycie",
    "Users" : "Użytkownicy",
    "Groups" : "Grupy",
    "Links" : "Linki",
    "Federated sent" : "Wysłane do federacji",
    "Federated received" : "Otrzymane z federacji",
    "Talk conversations" : "Rozmowy Talk",
    "Last 24 hours" : "Ostatnie 24 godziny",
    "Last 1 hour" : "Ostatnia 1 godzina",
    "Last 5 mins" : "Ostatnie 5 minut",
    "Copy" : "Kopiuj",
    "Copied!" : "Skopiowano!",
    "Not supported!" : "Niewspierane!",
    "Press ⌘-C to copy." : "Aby skopiować wciśnij ⌘-C.",
    "Press Ctrl-C to copy." : "Aby skopiować wciśnij Ctrl+C.",
    "Monitoring" : "Monitoring",
    "Monitoring app with useful server information" : "Aplikacja monitorująca z przydatnymi informacjami o serwerze",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Zapewnia przydatne informacje o serwerze, takie jak obciążenie procesora, użycie pamięci RAM, wykorzystanie dysku, liczba użytkowników itp.",
    "CPU load" : "Obciążenie procesora",
    "Memory usage" : "Użycie pamięci",
    "Active users" : "Aktywni użytkownicy",
    "Shares" : "Udziały",
    "Storage" : "Magazyn",
    "Users:" : "Użytkownicy:",
    "Files:" : "Pliki:",
    "Storages:" : "Magazyny: ",
    "Free Space:" : "Wolne miejsce: ",
    "Nextcloud" : "Nextcloud",
    "Version:" : "Wersja:",
    "Apps installed:" : "Zainstalowane aplikacje: ",
    "Apps updates available:" : "Dostępne aktualizacje aplikacji: ",
    "PHP" : "PHP",
    "Memory Limit:" : "Limit pamięci:",
    "Max Execution Time:" : "Maksymalny czas wykonania:",
    "Upload max size:" : "Limit wielkości przesyłanego pliku (upload_max_filesize):",
    "Database" : "Baza danych",
    "Type:" : "Rodzaj:",
    "Size:" : "Wielkość:",
    "External monitoring tool" : "Zewnętrzne narzędzie monitorujące",
    "You can connect an external monitoring tool by using this end point:" : "Możesz połączyć się z zewnętrznym narzędziem monitorującym używając tej końcówki: ",
    "Did you know?" : "Czy wiesz?",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON format!" : "Dołączenie \"?format=json\" na końcu URL daje wynik w formacie JSON!",
    "You can connect an external monitoring tool by using this end point: " : "Możesz połączyć zewnętrzne narzędzie monitorujące używając tego adresu:"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
